Gives the cumulative survival proportions at xx from extrinsic process for a given set of parameter values.
SurvFn.ex.4p(xx, r, s, lambda, beta)vector of ages
r value
s value
lambda value
beta value
vector of cumulative survival proportions at xx from extrinsic process
Used within vitality.4p for estimating model parameters based on the observed cumulative survival function.