Learn R Programming

vitality (version 1.0)

indexFinder: Finds the first value of a vector that is less than a value.

Description

None

Usage

indexFinder(x, val)

Arguments

x
Vector to serach
val
Threshhold

Value

  • Gives the index of the first value of x that is <= val.="" returns="" -1="" if="" no="" value="" satisfies="" the="" condition<="" li="">