Learn R Programming

vitality (version 1.0)

vitality.2ps: Fitting routine for the 2-process, 4-parameter vitality model (no childhood hook).

Description

Based on code by D.H. Salinger, J.J. Anderson and O. Hamel (2003). "A parameter fitting routine for the vitality based survival model." Ecological Modeling 166(3): 287--294.

Usage

vitality.2ps(time = 0:(1 - length(sdata)), sdata,
    init.params = FALSE, rc.data = FALSE, se = FALSE,
    datatype = c("CUM", "INC"), ttol = 1e-06, pplot = TRUE,
    Iplot = FALSE, Mplot = FALSE, tlab = "years",
    silent = FALSE)

Arguments

time
Vector. Time component of data: Defaults to 0:(1-length(sdata)).
sdata
Required. Survival or mortality data. The default expects cumulative survival fraction. If providing incremental mortality fraction instead, use option: datatype = "INC". The default also expects the data to represent full mortality. Other
rc.data
Optional, boolean. Specifies Right Censored data. If the data does not represent full mortality, it is probably right censored. The default is rc.data = F. A third option is rc.data = "TF". Use this case to add a near-term zero survival po
se
Optional, boolean. Calculates the standard errors for the MLE parameters. Default is FALSE. Set equal to the initial study population to compute standard errors.
datatype
Optional. Defaults to "CUM" for cumulative survival fraction data. Use "INC" - for incremental mortality fraction data.
ttol
Optional. Stopping criteria tolerance. Default is 1e-6. Specify as ttol = .0001. If one of the liklihood plots (esp. for "k") does not look optimal, try decreasing ttol. If the program crashes, try increasing ttol.
init.params
Optional. Please specify the initial param values. specify init.params = c(r, s, lambda, beta) in that order (eg. init.params = c(.1, .02, .3, 0.12)).
pplot
Optional, boolean. Plots of cumulative survival for both data and fitted curves? Default TRUE. FALSE Produce no plots. A A third option: pplot = n (n >= 1) extends the time axis of the fitting plots (bey
Iplot
Optional, boolean. Incremental mortality for both data and fitted curves? Default: FALSE.
Mplot
Optional, boolean. Plot fitted mortality curve? Default is FALSE.
tlab
Optional, character. specifies units for x-axis of plots. Default is "days".
silent
Optional, boolean. Stops all print and plot options (still get most warning and all error messages) Default is FALSE. A third option, "verbose" also enables the trace setting in the ms (minimum sum) S-Plus routine.

Value

  • vector of final MLE r, s, lambda, beta w/wo gamma and alpha parameter estimates. standard errors of MLE parameter estimates (if se = is specified).